@@ -13,18 +13,15 @@
 #ifndef SUBJECT_H
 #define SUBJECT_H
 
-#include "genetictimetable_defs.h"
+#include "timetable_defs.h"
 
-#include <qstring.h>
-#include <qptrlist.h>
+#include <QList>
+#include <QString>
 
 class Subject;
 class Rules;
 
-class SubjectsList: public QPtrList<Subject>
-{
-	int compareItems(QPtrCollection::Item, QPtrCollection::Item);
-};
+typedef QList<Subject*> SubjectsList;
 
 /**
 This class represents a subject
@@ -43,4 +40,6 @@ public:
 	QString getDetailedDescriptionWithConstraints(Rules& r);
 };
 
+int subjectsAscending(const Subject* s1, const Subject* s2);
+
 #endif
