@@ -21,10 +21,20 @@
 #include <qradiobutton.h>
 #include <qlabel.h>
 #include <qlineedit.h>
-#include <qtable.h>
+#include <q3table.h>
+
+#include <QDesktopWidget>
 
 AddConstraintActivitiesSameStartingHourForm::AddConstraintActivitiesSameStartingHourForm()
 {
+	//setWindowFlags(Qt::Window);
+	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);*/
+	centerWidgetOnScreen(this);
+	
 	updateActivitiesListBox();
 }
 
@@ -40,7 +50,8 @@ void AddConstraintActivitiesSameStartingHourForm::updateActivitiesListBox()
 	this->activitiesList.clear();
 	this->selectedActivitiesList.clear();
 
-	for(Activity* ac=gt.rules.activitiesList.first(); ac; ac=gt.rules.activitiesList.next()){
+	for(int i=0; i<gt.rules.activitiesList.size(); i++){
+		Activity* ac=gt.rules.activitiesList[i];
 		activitiesListBox->insertItem(ac->getDescription(gt.rules));
 		this->activitiesList.append(ac->id);
 	}
@@ -53,15 +64,15 @@ void AddConstraintActivitiesSameStartingHourForm::addConstraint()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	if(weight<0.0){
+	if(weight<0.0 || weight>100.0){
 		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid weight"));
+			QObject::tr("Invalid weight (percentage)"));
 		return;
 	}
 
-	bool compulsory=false;
+	/*bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
+		compulsory=true;*/
 
 	if(this->selectedActivitiesList.count()==0){
 		QMessageBox::warning(this, QObject::tr("FET information"),
@@ -73,7 +84,7 @@ void AddConstraintActivitiesSameStartingHourForm::addConstraint()
 			QObject::tr("Only one selected activity"));
 		return;
 	}
-	if(this->selectedActivitiesList.count()>(uint)(MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_HOUR)){
+	if(this->selectedActivitiesList.size()>MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_HOUR){
 		QMessageBox::warning(this, QObject::tr("FET information"),
 			QObject::tr("Please report error to the author\nMAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_HOUR must be increased (you have too many activities)"));
 		return;
@@ -81,11 +92,11 @@ void AddConstraintActivitiesSameStartingHourForm::addConstraint()
 	
 	int ids[MAX_CONSTRAINT_ACTIVITIES_SAME_STARTING_HOUR];
 	int i;
-	QValueList<int>::iterator it;
+	QList<int>::iterator it;
 	for(i=0, it=this->selectedActivitiesList.begin(); it!=this->selectedActivitiesList.end(); it++, i++)
 		ids[i]=*it;
 	
-	ctr=new ConstraintActivitiesSameStartingHour(weight, compulsory, this->selectedActivitiesList.count(), ids);
+	ctr=new ConstraintActivitiesSameStartingHour(weight, /*compulsory,*/ this->selectedActivitiesList.count(), ids);
 	bool tmp2=gt.rules.addTimeConstraint(ctr);
 	
 	if(tmp2){
@@ -106,7 +117,7 @@ void AddConstraintActivitiesSameStartingHourForm::addActivity()
 	if(activitiesListBox->currentItem()<0)
 		return;
 	int tmp=activitiesListBox->currentItem();
-	int _id=*(this->activitiesList.at(tmp));
+	int _id=this->activitiesList.at(tmp);
 	
 	QString actName=activitiesListBox->currentText();
 	assert(actName!="");
@@ -127,9 +138,7 @@ void AddConstraintActivitiesSameStartingHourForm::removeActivity()
 	if(selectedActivitiesListBox->currentItem()<0 || selectedActivitiesListBox->count()<=0)
 		return;		
 	int tmp=selectedActivitiesListBox->currentItem();
-	int _id=*(this->selectedActivitiesList.at(tmp));
 	
-	selectedActivitiesListBox->removeItem(selectedActivitiesListBox->currentItem());
-	int tmp2=this->selectedActivitiesList.remove(_id);
-	assert(tmp2==1);
+	selectedActivitiesListBox->removeItem(tmp);
+	this->selectedActivitiesList.removeAt(tmp);
 }
