@@ -1,8 +1,8 @@
 /***************************************************************************
                           addconstraintstudentssetintervalmaxdaysperweekform.h  -  description
                              -------------------
-    begin                : Feb 11, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
+    begin                : 2008
+    copyright            : (C) 2008 by Lalescu Liviu
     email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
@@ -19,27 +19,30 @@
 #define ADDCONSTRAINTSTUDENTSSETINTERVALMAXDAYSPERWEEKFORM_H
 
 #include "addconstraintstudentssetintervalmaxdaysperweekform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
+#include <q3combobox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
+#include <q3textedit.h>
 
 class AddConstraintStudentsSetIntervalMaxDaysPerWeekForm : public AddConstraintStudentsSetIntervalMaxDaysPerWeekForm_template  {
+	Q_OBJECT
 public:
 	AddConstraintStudentsSetIntervalMaxDaysPerWeekForm();
 	~AddConstraintStudentsSetIntervalMaxDaysPerWeekForm();
 
-	void updatePeriodGroupBox();
-	void updateStudentsSetComboBox();
+	void updateMaxDaysSpinBox();
+	void updateStudentsComboBox();
+	void updateStartHoursComboBox();
+	void updateEndHoursComboBox();
 
 	void constraintChanged();
 	void addCurrentConstraint();
