@@ -29,12 +29,13 @@
 AddRoomForm::AddRoomForm()
 {
 	//setWindowFlags(Qt::Window);
-	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
 	int xx=desktop->width()/2 - frameGeometry().width()/2;
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);
-
+	move(xx, yy);*/
+	centerWidgetOnScreen(this);
+	
 	/*typesComboBox->clear();
 	typesComboBox->setDuplicatesEnabled(false);
 	for(int i=0; i<gt.rules.roomsList.size(); i++){
@@ -131,9 +132,10 @@ void AddRoomForm::help()
 	connect(pb, SIGNAL(clicked()), dialog, SLOT(close()));
 
 	dialog->setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QDesktopWidget* desktop=QApplication::desktop();
-	int xx=desktop->width()/2 - 350;
-	int yy=desktop->height()/2 - 250;
+	//QDesktopWidget* desktop=QApplication::desktop();
+	QRect rect = QApplication::desktop()->availableGeometry(dialog);
+	int xx=rect.width()/2 - 350;
+	int yy=rect.height()/2 - 250;
 	dialog->setGeometry(xx, yy, 700, 500);
 
 	dialog->exec();
