@@ -24,12 +24,13 @@
 ConstraintBasicCompulsoryTimeForm::ConstraintBasicCompulsoryTimeForm()
 {
 	//setWindowFlags(Qt::Window);
-	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QDesktopWidget* desktop=QApplication::desktop();
+	//setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	/*QDesktopWidget* desktop=QApplication::desktop();
 	int xx=desktop->width()/2 - frameGeometry().width()/2;
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);
-
+	move(xx, yy);*/
+	centerWidgetOnScreen(this);
+	
 	this->filterChanged();
 }
 
