@@ -1,8 +1,8 @@
 /***************************************************************************
                           constraintstudentssetintervalmaxdaysperweekform.h  -  description
                              -------------------
-    begin                : Feb 11, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
+    begin                : 2008
+    copyright            : (C) 2008 by Lalescu Liviu
     email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
@@ -19,22 +19,23 @@
 #define CONSTRAINTSTUDENTSSETINTERVALMAXDAYSPERWEEKFORM_H
 
 #include "constraintstudentssetintervalmaxdaysperweekform_template.h"
-#include "genetictimetable_defs.h"
-#include "genetictimetable.h"
+#include "timetable_defs.h"
+#include "timetable.h"
 #include "fet.h"
-#include "fetmainform.h"
+//#include "fetmainform.h"
 
-#include <qcombobox.h>
+#include <q3combobox.h>
 #include <qmessagebox.h>
-#include <qgroupbox.h>
+#include <q3groupbox.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
 #include <qpushbutton.h>
 #include <qlineedit.h>
-#include <qtextedit.h>
-#include <qlistbox.h>
+#include <q3textedit.h>
+#include <q3listbox.h>
 
 class ConstraintStudentsSetIntervalMaxDaysPerWeekForm : public ConstraintStudentsSetIntervalMaxDaysPerWeekForm_template  {
+	Q_OBJECT
 public:
 	TimeConstraintsList visibleConstraintsList;
 
