@@ -30,7 +30,7 @@ class FetMainForm:public QMainWindow, Ui::FetMainForm_template
 public:
 	FetMainForm();
 	~FetMainForm();
-
+	
 public slots:
 	void on_fileNewAction_activated();
 	void on_fileSaveAction_activated();
@@ -38,6 +38,14 @@ public slots:
 	void on_fileExitAction_activated();
 	void on_fileOpenAction_activated();
 
+	void on_fileImportCSVActivityTagsAction_activated();
+	void on_fileImportCSVActivitiesAction_activated();
+	void on_fileImportCSVRoomsBuildingsAction_activated();
+	void on_fileImportCSVSubjectsAction_activated();
+	void on_fileImportCSVTeachersAction_activated();
+	void on_fileImportCSVYearsGroupsSubgroupsAction_activated();
+	void on_fileExportCSVAction_activated();
+							
 	void on_dataInstitutionNameAction_activated();
 	void on_dataCommentsAction_activated();
 	void on_dataDaysAction_activated();
@@ -95,15 +103,21 @@ public slots:
 
 	void on_dataTimeConstraints2ActivitiesConsecutiveAction_activated();
 	void on_dataTimeConstraints2ActivitiesOrderedAction_activated();
-	void on_dataTimeConstraintsActivityPreferredTimeAction_activated();
-	void on_dataTimeConstraintsActivityPreferredTimesAction_activated();
-	void on_dataTimeConstraintsActivitiesPreferredTimesAction_activated();
+	void on_dataTimeConstraintsActivityPreferredStartingTimeAction_activated();
+	void on_dataTimeConstraintsActivityPreferredTimeSlotsAction_activated();
+	void on_dataTimeConstraintsActivitiesPreferredTimeSlotsAction_activated();
+	void on_dataTimeConstraintsSubactivitiesPreferredTimeSlotsAction_activated();
+	void on_dataTimeConstraintsActivityPreferredStartingTimesAction_activated();
+	void on_dataTimeConstraintsActivitiesPreferredStartingTimesAction_activated();
+	void on_dataTimeConstraintsSubactivitiesPreferredStartingTimesAction_activated();
 	void on_dataTimeConstraintsActivitiesSameStartingTimeAction_activated();
 	void on_dataTimeConstraintsActivitiesSameStartingHourAction_activated();
 	void on_dataTimeConstraintsActivitiesSameStartingDayAction_activated();
 	void on_dataTimeConstraintsActivitiesNotOverlappingAction_activated();
 	void on_dataTimeConstraintsMinNDaysBetweenActivitiesAction_activated();
+	void on_dataTimeConstraintsMinGapsBetweenActivitiesAction_activated();
 	void on_dataTimeConstraintsActivityEndsStudentsDayAction_activated();
+	void on_dataTimeConstraintsActivitiesEndStudentsDayAction_activated();
 
 	void on_dataTimeConstraintsTeacherNotAvailableTimesAction_activated();
 	void on_dataTimeConstraintsTeacherMaxDaysPerWeekAction_activated();
@@ -117,6 +131,11 @@ public slots:
 	void on_dataTimeConstraintsTeacherMaxGapsPerWeekAction_activated();
 	void on_dataTimeConstraintsTeachersMaxGapsPerDayAction_activated();
 	void on_dataTimeConstraintsTeacherMaxGapsPerDayAction_activated();
+	
+	void on_dataTimeConstraintsTeacherIntervalMaxDaysPerWeekAction_activated();
+	void on_dataTimeConstraintsTeachersIntervalMaxDaysPerWeekAction_activated();
+	void on_dataTimeConstraintsStudentsSetIntervalMaxDaysPerWeekAction_activated();
+	void on_dataTimeConstraintsStudentsIntervalMaxDaysPerWeekAction_activated();
 
 	void on_dataTimeConstraintsStudentsSetNotAvailableTimesAction_activated();
 	void on_dataTimeConstraintsStudentsSetMaxGapsPerWeekAction_activated();
@@ -130,11 +149,14 @@ public slots:
 	void on_dataTimeConstraintsStudentsMinHoursDailyAction_activated();
 	void on_dataTimeConstraintsStudentsSetMinHoursDailyAction_activated();
 
+	void on_spreadActivitiesAction_activated();
 
 	void on_helpAboutAction_activated();
 	void on_helpFAQAction_activated();
+	void on_helpTipsAction_activated();
 	void on_helpInstructionsAction_activated();
 	void on_helpInOtherLanguagesAction_activated();
+	void on_helpForumAction_activated();
 
 	void on_timetableGenerateAction_activated();
 	void on_timetableViewStudentsAction_activated();
@@ -161,12 +183,14 @@ public slots:
 	void on_languageArabicAction_activated();
 	void on_languageIndonesianAction_activated();
 	void on_languageItalianAction_activated();
+	void on_languageLithuanianAction_activated();
 	
 	void on_checkForUpdatesAction_toggled();
 
 	void on_settingsRestoreDefaultsAction_activated();
 
 	void on_settingsTimetableHtmlLevelAction_activated();
+	void on_settingsPrintNotAvailableSlotsAction_toggled();
 	
 	void httpDone(bool error);
 	
