@@ -50,12 +50,13 @@
 ModifyActivityForm::ModifyActivityForm(int id, int activityGroupId)
 {
 	//setWindowFlags(Qt::Window);
-	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
 	int xx=desktop->width()/2 - frameGeometry().width()/2;
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);
-
+	move(xx, yy);*/
+	centerWidgetOnScreen(this);
+	
 	this->_id=id;
 	this->_activityGroupId=activityGroupId;
 	for(int i=0; i<gt.rules.activitiesList.size(); i++){
