@@ -30,15 +30,18 @@
 ModifyConstraintMinNDaysBetweenActivitiesForm::ModifyConstraintMinNDaysBetweenActivitiesForm(ConstraintMinNDaysBetweenActivities* ctr)
 {
 	//setWindowFlags(Qt::Window);
-	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
 	int xx=desktop->width()/2 - frameGeometry().width()/2;
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);
-
-	this->_ctr=ctr;
-	updateActivitiesListBox();
+	move(xx, yy);*/
+	centerWidgetOnScreen(this);
 	
+	this->_ctr=ctr;
+	//updateActivitiesListBox();
+
+	selectedActivitiesList.clear();
+	selectedActivitiesListBox->clear();	
 	for(int i=0; i<ctr->n_activities; i++){
 		int actId=ctr->activitiesId[i];
 		this->selectedActivitiesList.append(actId);
@@ -59,27 +62,111 @@ ModifyConstraintMinNDaysBetweenActivitiesForm::ModifyConstraintMinNDaysBetweenAc
 	//compulsoryCheckBox->setChecked(ctr->compulsory);
 	consecutiveIfSameDayCheckBox->setChecked(ctr->consecutiveIfSameDay);
 	weightLineEdit->setText(QString::number(ctr->weightPercentage));
+
+	////////////////
+	teachersComboBox->insertItem("");
+	for(int i=0; i<gt.rules.teachersList.size(); i++){
+		Teacher* tch=gt.rules.teachersList[i];
+		teachersComboBox->insertItem(tch->name);
+	}
+	teachersComboBox->setCurrentItem(0);
+
+	subjectsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.subjectsList.size(); i++){
+		Subject* sb=gt.rules.subjectsList[i];
+		subjectsComboBox->insertItem(sb->name);
+	}
+	subjectsComboBox->setCurrentItem(0);
+
+	activityTagsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.activityTagsList.size(); i++){
+		ActivityTag* st=gt.rules.activityTagsList[i];
+		activityTagsComboBox->insertItem(st->name);
+	}
+	activityTagsComboBox->setCurrentItem(0);
+
+	studentsComboBox->insertItem("");
+	for(int i=0; i<gt.rules.yearsList.size(); i++){
+		StudentsYear* sty=gt.rules.yearsList[i];
+		studentsComboBox->insertItem(sty->name);
+		for(int j=0; j<sty->groupsList.size(); j++){
+			StudentsGroup* stg=sty->groupsList[j];
+			studentsComboBox->insertItem(stg->name);
+			for(int k=0; k<stg->subgroupsList.size(); k++){
+				StudentsSubgroup* sts=stg->subgroupsList[k];
+				studentsComboBox->insertItem(sts->name);
+			}
+		}
+	}
+	studentsComboBox->setCurrentItem(0);
+
+	filterChanged();
 }
 
 ModifyConstraintMinNDaysBetweenActivitiesForm::~ModifyConstraintMinNDaysBetweenActivitiesForm()
 {
 }
 
-void ModifyConstraintMinNDaysBetweenActivitiesForm::updateActivitiesListBox()
+void ModifyConstraintMinNDaysBetweenActivitiesForm::filterChanged()
 {
 	activitiesListBox->clear();
-	selectedActivitiesListBox->clear();
+//	selectedActivitiesListBox->clear();
 
 	this->activitiesList.clear();
-	this->selectedActivitiesList.clear();
+//	this->selectedActivitiesList.clear();
 
 	for(int i=0; i<gt.rules.activitiesList.size(); i++){
 		Activity* ac=gt.rules.activitiesList[i];
-		activitiesListBox->insertItem(ac->getDescription(gt.rules));
-		this->activitiesList.append(ac->id);
+		if(filterOk(ac)){
+			activitiesListBox->insertItem(ac->getDescription(gt.rules));
+			this->activitiesList.append(ac->id);
+		}
 	}
 }
 
+bool ModifyConstraintMinNDaysBetweenActivitiesForm::filterOk(Activity* act)
+{
+	QString tn=teachersComboBox->currentText();
+	QString stn=studentsComboBox->currentText();
+	QString sbn=subjectsComboBox->currentText();
+	QString sbtn=activityTagsComboBox->currentText();
+	int ok=true;
+
+	//teacher
+	if(tn!=""){
+		bool ok2=false;
+		for(QStringList::Iterator it=act->teachersNames.begin(); it!=act->teachersNames.end(); it++)
+			if(*it == tn){
+				ok2=true;
+				break;
+			}
+		if(!ok2)
+			ok=false;
+	}
+
+	//subject
+	if(sbn!="" && sbn!=act->subjectName)
+		ok=false;
+		
+	//activity tag
+	if(sbtn!="" && sbtn!=act->activityTagName)
+		ok=false;
+		
+	//students
+	if(stn!=""){
+		bool ok2=false;
+		for(QStringList::Iterator it=act->studentsNames.begin(); it!=act->studentsNames.end(); it++)
+			if(*it == stn){
+				ok2=true;
+				break;
+			}
+		if(!ok2)
+			ok=false;
+	}
+	
+	return ok;
+}
+
 void ModifyConstraintMinNDaysBetweenActivitiesForm::ok()
 {
 	double weight;
