@@ -1,8 +1,8 @@
 /***************************************************************************
                           modifyconstraintstudentssetintervalmaxdaysperweekform.cpp  -  description
                              -------------------
-    begin                : Feb 11, 2005
-    copyright            : (C) 2005 by Lalescu Liviu
+    begin                : 2008
+    copyright            : (C) 2008 by Lalescu Liviu
     email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
@@ -22,21 +22,38 @@
 #include <qlabel.h>
 #include <qlineedit.h>
 
-#define yesNo(x)	((x)==0?QObject::tr("no"):QObject::tr("yes"))
+#include <QDesktopWidget>
 
 ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm::ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm(ConstraintStudentsSetIntervalMaxDaysPerWeek* ctr)
 {
+	//setWindowFlags(Qt::Window);
+	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	QDesktopWidget* desktop=QApplication::desktop();
+	int xx=desktop->width()/2 - frameGeometry().width()/2;
+	int yy=desktop->height()/2 - frameGeometry().height()/2;
+	move(xx, yy);*/
+	centerWidgetOnScreen(this);
+	
 	this->_ctr=ctr;
 	
-	compulsoryCheckBox->setChecked(ctr->compulsory);
-	weightLineEdit->setText(QString::number(ctr->weight));
+	//compulsoryCheckBox->setChecked(ctr->compulsory);
+	weightLineEdit->setText(QString::number(ctr->weightPercentage));
 	
-	updatePeriodGroupBox();
+	updateMaxDaysSpinBox();
 	updateStudentsComboBox();
+	
+	maxDaysSpinBox->setValue(ctr->maxDaysPerWeek);
+	
+	for(int i=0; i<gt.rules.nHoursPerDay; i++){
+		startHourComboBox->insertItem(gt.rules.hoursOfTheDay[i]);
+	}
+	startHourComboBox->setCurrentItem(ctr->startHour);
 
-	startHourComboBox->setCurrentItem(ctr->h1);
-	endHourComboBox->setCurrentItem(ctr->h2);
-	maxDaysSpinBox->setValue(ctr->n);
+	for(int i=0; i<gt.rules.nHoursPerDay; i++){
+		endHourComboBox->insertItem(gt.rules.hoursOfTheDay[i]);
+	}
+	endHourComboBox->insertItem(tr("End of day"));
+	endHourComboBox->setCurrentItem(ctr->endHour);
 
 	constraintChanged();
 }
@@ -48,17 +65,20 @@ ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm::~ModifyConstraintStudents
 void ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateStudentsComboBox(){
 	studentsComboBox->clear();
 	int i=0, j=-1;
-	for(StudentsYear* sty=gt.rules.yearsList.first(); sty; sty=gt.rules.yearsList.next()){
+	for(int m=0; m<gt.rules.yearsList.size(); m++){
+		StudentsYear* sty=gt.rules.yearsList[m];
 		studentsComboBox->insertItem(sty->name);
 		if(sty->name==this->_ctr->students)
 			j=i;
 		i++;
-		for(StudentsGroup* stg=sty->groupsList.first(); stg; stg=sty->groupsList.next()){
+		for(int n=0; n<sty->groupsList.size(); n++){
+			StudentsGroup* stg=sty->groupsList[n];
 			studentsComboBox->insertItem(stg->name);
 			if(stg->name==this->_ctr->students)
 				j=i;
 			i++;
-			for(StudentsSubgroup* sts=stg->subgroupsList.first(); sts; sts=stg->subgroupsList.next()){
+			for(int p=0; p<stg->subgroupsList.size(); p++){
+				StudentsSubgroup* sts=stg->subgroupsList[p];
 				studentsComboBox->insertItem(sts->name);
 				if(sts->name==this->_ctr->students)
 					j=i;
@@ -72,15 +92,7 @@ void ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateStudentsComboB
 	constraintChanged();
 }
 
-void ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm::updatePeriodGroupBox(){
-	startHourComboBox->clear();
-	for(int i=0; i<=gt.rules.nHoursPerDay; i++)
-		startHourComboBox->insertItem(gt.rules.hoursOfTheDay[i]);
-
-	endHourComboBox->clear();
-	for(int i=0; i<=gt.rules.nHoursPerDay; i++)
-		endHourComboBox->insertItem(gt.rules.hoursOfTheDay[i]);
-
+void ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm::updateMaxDaysSpinBox(){
 	maxDaysSpinBox->setMinValue(0);
 	maxDaysSpinBox->setMaxValue(gt.rules.nDaysPerWeek);	
 }
@@ -88,49 +100,29 @@ void ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm::updatePeriodGroupBox
 void ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm::constraintChanged()
 {
 	QString s;
-	s+=QObject::tr("Current constraint:");
+	s+=tr("Current constraint:");
 	s+="\n";
 
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	s+=QObject::tr(QString("Weight=%1").arg(weight));
+	s+=tr("Weight (percentage)=%1\%").arg(weight);
 	s+="\n";
 
-	bool compulsory=false;
-	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
-	s+=QObject::tr("Compulsory=%1").arg(yesNo(compulsory));
+	s+=tr("Students set interval max days per week");
+	s+="\n";
+	s+=tr("Students set=%1").arg(studentsComboBox->currentText());
+	s+="\n";
+	
+	s+=tr("Interval start hour=%1").arg(startHourComboBox->currentText());
 	s+="\n";
 
-	s+=QObject::tr("Students set interval max days per week");
-	s+="\n";
-	s+=QObject::tr("Students set=%1").arg(studentsComboBox->currentText());
+	s+=tr("Interval end hour=%1").arg(endHourComboBox->currentText());
 	s+="\n";
 
-	s+=QObject::tr("Max days=%1").arg(maxDaysSpinBox->value());
+	s+=tr("Max days per week=%1").arg(maxDaysSpinBox->value());
 	s+="\n";
 
-	int startHour=startHourComboBox->currentItem();
-	if(startHour<0 || startHour>gt.rules.nHoursPerDay){
-		s+=QObject::tr("Invalid start hour");
-		s+="\n";
-	}
-	else{
-		s+=QObject::tr("Start hour:%1").arg(startHourComboBox->currentText());
-		s+="\n";
-	}
-
-	int endHour=endHourComboBox->currentItem();
-	if(endHour<0 || endHour>gt.rules.nHoursPerDay){
-		s+=QObject::tr("Invalid end hour");
-		s+="\n";
-	}
-	else{
-		s+=QObject::tr("End hour:%1").arg(endHourComboBox->currentText());
-		s+="\n";
-	}
-
 	currentConstraintTextEdit->setText(s);
 }
 
@@ -139,49 +131,56 @@ void ModifyConstraintStudentsSetIntervalMaxDaysPerWeekForm::ok()
 	double weight;
 	QString tmp=weightLineEdit->text();
 	sscanf(tmp, "%lf", &weight);
-	if(weight<0.0){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid weight"));
+	if(weight<0.0 || weight>100.0){
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid weight (percentage)"));
+		return;
+	}
+	if(weight!=100.0){
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid weight (percentage) - it has to be 100%"));
 		return;
 	}
 
-	bool compulsory=false;
+	/*bool compulsory=false;
 	if(compulsoryCheckBox->isChecked())
-		compulsory=true;
+		compulsory=true;*/
 
-	int startHour=startHourComboBox->currentItem();
-	if(startHour<0 || startHour>gt.rules.nHoursPerDay){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid start hour"));
-		return;
-	}
-	int endHour=-1;
-	endHour=endHourComboBox->currentItem();
-	if(endHour<0 || endHour>gt.rules.nHoursPerDay){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid end hour"));
-		return;
-	}
-	if(endHour<=startHour){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("End hour <= start hour - impossible"));
-		return;
-	}
+	int max_days=maxDaysSpinBox->value();
 
 	QString students_name=studentsComboBox->currentText();
 	StudentsSet* s=gt.rules.searchStudentsSet(students_name);
 	if(s==NULL){
-		QMessageBox::warning(this, QObject::tr("FET information"),
-			QObject::tr("Invalid students set"));
+		QMessageBox::warning(this, tr("FET information"),
+			tr("Invalid students set"));
+		return;
+	}
+	
+	int startHour=startHourComboBox->currentItem();
+	int endHour=endHourComboBox->currentItem();
+	if(startHour<0 || startHour>=gt.rules.nHoursPerDay){
+		QMessageBox::warning(this, tr("FET information"),
+		 tr("Start hour invalid"));
+		return;
+	}
+	if(endHour<0 || endHour>gt.rules.nHoursPerDay){
+		QMessageBox::warning(this, tr("FET information"),
+		 tr("End hour invalid"));
+		return;
+	}
+	if(endHour<=startHour){
+		QMessageBox::warning(this, tr("FET information"),
+		 tr("Start hour cannot be greater or equal than end hour"));
 		return;
 	}
 
-	this->_ctr->weight=weight;
-	this->_ctr->compulsory=compulsory;
+	this->_ctr->weightPercentage=weight;
+	//this->_ctr->compulsory=compulsory;
+	this->_ctr->maxDaysPerWeek=max_days;
 	this->_ctr->students=students_name;
-	this->_ctr->h1=startHour;
-	this->_ctr->h2=endHour;
-	this->_ctr->n=maxDaysSpinBox->value();
+
+	this->_ctr->startHour=startHour;
+	this->_ctr->endHour=endHour;
 
 	gt.rules.internalStructureComputed=false;
 	
