@@ -32,12 +32,13 @@ TeachersStatisticsForm::TeachersStatisticsForm()
 	setupUi(this);
 
 	//setWindowFlags(Qt::Window);
-	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
-	QDesktopWidget* desktop=QApplication::desktop();
+	//setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	/*QDesktopWidget* desktop=QApplication::desktop();
 	int xx=desktop->width()/2 - frameGeometry().width()/2;
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);
-	
+	move(xx, yy);*/
+	centerWidgetOnScreen(this);
+		
 	tableWidget->setColumnCount(3);
 	tableWidget->setRowCount(gt.rules.teachersList.size());
 	
