@@ -51,15 +51,19 @@ extern bool simulation_running;
 extern Solution best_solution;
 extern SpaceChromosome best_space_chromosome;
 
+extern double notAllowedRoomTimePercentages[MAX_ROOMS][MAX_HOURS_PER_WEEK];
+extern bool breakDayHour[MAX_DAYS_PER_WEEK][MAX_HOURS_PER_DAY];
+
 TimetableViewRoomsForm::TimetableViewRoomsForm()
 {
 	//setWindowFlags(Qt::Window);
-	setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
+	/*setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
 	QDesktopWidget* desktop=QApplication::desktop();
 	int xx=desktop->width()/2 - frameGeometry().width()/2;
 	int yy=desktop->height()/2 - frameGeometry().height()/2;
-	move(xx, yy);
-	
+	move(xx, yy);*/
+	centerWidgetOnScreen(this);
+		
 	roomsListBox->clear();
 	for(int i=0; i<gt.rules.nInternalRooms; i++)
 		roomsListBox->insertItem(gt.rules.internalRoomsList[i]->name);
@@ -118,6 +122,16 @@ void TimetableViewRoomsForm::updateRoomsTimetableTable(){
 				assert(act!=NULL);
 				s += act->subjectName + " " + act->activityTagName;
 			}
+			else{
+				if((notAllowedRoomTimePercentages[roomIndex][k+j*gt.rules.nDaysPerWeek]>=0 || breakDayHour[k][j])
+				 && PRINT_NOT_AVAILABLE_TIME_SLOTS)
+					s+="-x-";
+				/*if(!breakDayHour[k][j] && notAllowedRoomTimePercentages[roomIndex][k+j*gt.rules.nDaysPerWeek]>=0 && notAllowedRoomTimePercentages[roomIndex][k+j*gt.rules.nDaysPerWeek]<100.0){
+					s+="\n";
+					s+=QString::number(notAllowedRoomTimePercentages[roomIndex][k+j*gt.rules.nDaysPerWeek]);
+					s+="%";
+				}*/
+			}
 			roomsTimetableTable->setText(j, k, s);
 		}
 	}
@@ -152,6 +166,16 @@ void TimetableViewRoomsForm::detailActivity(int row, int col){
 			assert(act!=NULL);
 			s += act->getDetailedDescriptionWithConstraints(gt.rules);
 		}
+		else{
+			if(notAllowedRoomTimePercentages[roomIndex][k+j*gt.rules.nDaysPerWeek]>=0){
+				s+=tr("Room is not available with weight %1%").arg(notAllowedRoomTimePercentages[roomIndex][k+j*gt.rules.nDaysPerWeek]);
+				s+="\n";
+			}
+			if(breakDayHour[k][j]){
+				s+=tr("Break with weight 100% in this slot");
+				s+="\n";
+			}
+		}
 	}
 	detailsTextEdit->setText(s);
 }
@@ -206,7 +230,7 @@ void TimetableViewRoomsForm::lock(bool lockTime, bool lockSpace)
 
 					Activity* act=&gt.rules.internalActivitiesList[ai];
 					if(lockTime){
-						ConstraintActivityPreferredTime* ctr=new ConstraintActivityPreferredTime(100.0, act->id, day, hour);
+						ConstraintActivityPreferredStartingTime* ctr=new ConstraintActivityPreferredStartingTime(100.0, act->id, day, hour);
 						bool t=gt.rules.addTimeConstraint(ctr);
 						
 						if(t)
